function lwn = lw2lwn(lw, sdn, lat, lon, lambda)
% LW2LWN    - Solar-normalize water-leaving radiance
%
% Use as: Lwn = lw2lwn(Lw, sdn, lat, lon, lambda)
%
% Inputs: Lw     = Water-leaving radiance
%         sdn    = Date in matlab's date format (see DATENUM)
%         lat    = Decimal degrees latitude of the mooring (+N -S)
%         lon    = Decimal degrees longitude of the mooring (-W +E)
%         lambda = wavelength of measurement (nm)
%
% Output: Lwn = Solar-normalized water-leavng radiance

% Brian Schlining
% 15 Mar 2000

lwn = lw./calc_fn(sdn, lat, lon, lambda);
